# Visualizer Logic

## Get Started

```html

<html>
  <head>
    <link
      href="https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@{version}/build/index.css"
      rel="stylesheet"
    />
  </head>
  <body>

    <div
        class="visualizer"
        data-role="visualizer"
        experienceId="<your experience id, optional if using hashExperienceId>"
        hashExperienceId="<your hashed experience id, optional if using experienceId>"
        sceneConfigurationLabel="<optional, the maximum width image size to use on mobile, a number from 0 to 2048>"
        sceneId="<optional, will lunch a scene by scene id>"
        defaultProduct="<optional, product sku, will display the product on all available supported application>"
        defaultProducts="<optional, a stringified key vale pair, key: application, value: product sku, will present those as defaults >"
        maxFaceSize="<optional, the maximum width image size to use, a number from 0 to 2048>"
        maxFaceSizeMobile="<optional, the maximum width image size to use on mobile, a number from 0 to 2048>"
        >
    </div>
        const containerElement = document.querySelector('[data-role="visualizer"]');
        containerElement.addEventListener('visualizerLoaded', (event)=>{
            const visualizer = event.detail.visualizer;
        });
    </div>
    <script src="https://unpkg.com/@byondrnd/byondxr-web-visualizer@2.0.29/dist/index.js"></script>
    <script src="https://unpkg.com/@byondrnd/byondxr-web-visualizer-ui@{version}/build/index.js"></script>
  </body>
</html>  
```

## Documentation
<https://unpkg.com/@byondrnd/byondxr-web-visualizer@2.0.29/doc/index.html>

## Plugins

### UI plugin
<https://www.npmjs.com/package/@byondrnd/byondxr-web-visualizer-ui>

### Favorites

```ts
    /** set favorite scene */
    abstract setFavoriteScenes(favoriteScenes: IFavoriteSceneList);

    /** set favorite product */
    abstract setFavoriteProducts(favoriteProducts: IFavoriteProductList);

```

**Code example:**

```ts
// subscribe to events that save favorites localstorage
let subscribe = (container) => {
    container.Visualizer.addListener('productAddedToFavorites',(param)=>{
        localStorage.setItem('favoriteProducts', JSON.stringify(param.favorites))
    })
    container.Visualizer.addListener('sceneAddedToFavorites',(param)=>{
        localStorage.setItem('favoriteScenes', JSON.stringify(param.favoriteScenes))
    })
}
```

Need to acquire the container of the Visualizer
If the container already in the page from the start, then acquire it and subscribe:

```ts
container = document.querySelector('[data-role="visualizer"]');
subscribe(container)
```

If the container is not there beause it will be launched, then use the launchVisualizer promise to acquire the container

```html
        <button
            onClick={() => {
                window.launchVisualizer({
                    experienceId: 'G2GcP2',
                    defaultProducts: { Countertop: '1200302000' },
                    defaultProduct: '1200302000',
                    sceneId: '6',
                    scene_configuration: 'US-EN',
                }).then((visualizerContainer)=>{
                    // Here the visualizer is loaded and you can do with it whatever you need
                    subcribe(visualizerContainer)
                })
            }}
        >
            Launch
        </button>
```

+++++++++ User adds products and scenes to favorites +++++++++

```ts
// upon new start of application, read from localstorage
ce.Visualizer.setFavoriteProducts(JSON.parse(localStorage.getItem('favoriteProducts')))
ce.Visualizer.setFavoriteScenes(JSON.parse(localStorage.getItem('favoriteScenes')))
```
